FROM THE SLUMS OF SHAOLIN, LOREM IPSUM STRIKES AGAIN
====================================================

LOREM IPSUM GENERATOR, BUT WITH THE WUTANG CLAN.

`SO YOU CAN PLAY THAT WUTANG JOINT AGAIN AND AGAIN, AH YEAH. <https://www.youtube.com/watch?v=Q6MFdq3Yd38>`_
